@@ -1,7 +1,7 @@
 from django.apps import AppConfig
 from django.conf import settings
 from django.db.backends.signals import connection_created
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from django_mysql.checks import register_checks
 from django_mysql.rewrite_query import REWRITE_MARKER, rewrite_query
