@@ -1,4 +1,3 @@
-import django
 from django.core.management import call_command
 from django.test import TestCase, TransactionTestCase
 
@@ -8,10 +7,7 @@ from django_mysql.test.utils import override_mysql_variables
 
 class CallCheckTest(TestCase):
 
-    if django.VERSION >= (2, 2):
-        databases = ["default", "other"]
-    else:
-        multi_db = True
+    databases = ["default", "other"]
 
     def test_check(self):
         call_command("check")
@@ -19,10 +15,7 @@ class CallCheckTest(TestCase):
 
 class VariablesTests(TransactionTestCase):
 
-    if django.VERSION >= (2, 2):
-        databases = ["default", "other"]
-    else:
-        multi_db = True
+    databases = ["default", "other"]
 
     def test_passes(self):
         assert check_variables([]) == []
